@@ -57,7 +57,7 @@ class Font:
             w += _w
         return r
 
-_widths = {unichr(i) : 600 for i in range(256)}
+_widths = {chr(i) : 600 for i in range(256)}
 COURIER = Font("Type1", "Courier", _widths)
 COURIER_BOLD = Font("Type1", "Courier-Bold", _widths)
 COURIER_OBLIQUE = Font("Type1", "Courier-Oblique", _widths)
@@ -77,7 +77,7 @@ l = 278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,\
     584,778,722,722,722,722,667,667,611,556,556,556,556,556,556,889,500,556,\
     556,556,556,278,278,278,278,556,556,556,556,556,556,556,584,611,556,556,\
     556,556,500,556,500
-_widths = {unichr(i) : l[i] for i in range(256)}
+_widths = {chr(i) : l[i] for i in range(256)}
 HELVETICA = Font("Type1", "Helvetica", _widths)
 
 l = 278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,\
@@ -96,7 +96,7 @@ l = 278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,278,\
     556,556,556,556,278,278,278,278,611,611,611,611,611,611,611,584,611,611,\
     611,611,611,556,611,556
 
-_widths = {unichr(i) : l[i] for i in range(256)}
+_widths = {chr(i) : l[i] for i in range(256)}
 HELVETICA_BOLD = Font("Type1", "Helvetica-Bold", _widths)
 
 l = 250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,\
@@ -114,7 +114,7 @@ l = 250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,\
     722,722,722,722,722,722,556,500,444,444,444,444,444,444,667,444,444,444,\
     444,444,278,278,278,278,500,500,500,500,500,500,500,564,500,500,500,500,\
     500,500,500,500
-_widths = {unichr(i) : l[i] for i in range(256)}
+_widths = {chr(i) : l[i] for i in range(256)}
 TIMES = Font("Type1", "Times", _widths)
 
 
@@ -276,6 +276,17 @@ def grow(rect, d):
 
 def create_pdf(text, outfile, twoup=True, fontsize=None, pagesize=A4,
                title='', printed_by='', file_date=''):
+    """Convert a string with python code to pdf. 
+
+       Args:
+         text: s string (not unicode!) containing the python source
+         outfile: a file objecte for output (must be opened with "wb")
+         fonsize: the fontsize default is 8 in twoup-mode and 10 otherwise
+         pagesize: a tuple describing the pagesize, e.g. (595.28, 841.89) for A4
+         title: the page title (usaually the filename)
+         printed_by: you can provide a string such as "printed by CE"
+         file_date: the date of the file, will be printed when given
+    """
     if fontsize is None:
         if twoup:
             fontsize = 8
@@ -423,14 +434,13 @@ def create_pdf(text, outfile, twoup=True, fontsize=None, pagesize=A4,
 
             lastfontinfo = None
             for l in frame_group:
-                #print l
                 for s, fontinfo in l:
                     if fontinfo != lastfontinfo:
                         font, size = fontinfo
                         fontname = fontnames[font]
                         out("/%s %s Tf\n" % (fontname, size))
                         lastfontinfo = fontinfo
-                    out("(%s)Tj\n" % quote(s).encode('latin-1'))
+                    out("(%s)Tj\n" % quote(s))
                 out("()'\n")
             out("ET\n")
         out("Q\n") # restore state
@@ -510,8 +520,8 @@ def startfile(filename):
 
     
 if __name__ == '__main__':
-    text = open('py2pdf.py').read().decode('latin-1')
+    text = open('etc/samplecode.py').read()
     f = open('tmp.pdf', 'wb')
-    create_pdf(text, f, title='py2pdf', pagesize=A5,
-               printed_by='Printed by ME', file_date='2020-08-01')
-    
+    create_pdf(text, f, title='py2pdf', pagesize=A4,
+               printed_by='Printed by CE', file_date='2020-08-01')
+    startfile('tmp.pdf')
